@@ -11,7 +11,7 @@
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
+ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1335  USA */
 
 #ifndef MY_CONFIG_H
 #define MY_CONFIG_H
@@ -21,7 +21,6 @@
 #define _GNU_SOURCE 1
 #define HAVE_ALLOCA_H 1
 #define HAVE_ARPA_INET_H 1
-/* #undef HAVE_ASM_MSR_H */
 #define HAVE_ASM_TERMBITS_H 1
 #define HAVE_CRYPT_H 1
 #define HAVE_CURSES_H 1
@@ -81,7 +80,7 @@
 #define HAVE_SYS_STAT_H 1
 /* #undef HAVE_SYS_STREAM_H */
 #define HAVE_SYS_SYSCALL_H 1
-#define HAVE_SYS_TIMEB_H 1
+/* #undef HAVE_SYS_TIMEB_H */
 #define HAVE_SYS_TIMES_H 1
 #define HAVE_SYS_TIME_H 1
 #define HAVE_SYS_TYPES_H 1
@@ -184,12 +183,8 @@
 #define HAVE_PERROR 1
 #define HAVE_POLL 1
 #define HAVE_POSIX_FALLOCATE 1
-#define HAVE_LINUX_FALLOC_H 1
 #define HAVE_FALLOC_PUNCH_HOLE_AND_KEEP_SIZE 1
 #define HAVE_PREAD 1
-/* #undef HAVE_PAUSE_INSTRUCTION */
-/* #undef HAVE_FAKE_PAUSE_INSTRUCTION */
-/* #undef HAVE_RDTSCLL */
 /* #undef HAVE_READ_REAL_TIME */
 /* #undef HAVE_PTHREAD_ATTR_CREATE */
 #define HAVE_PTHREAD_ATTR_GETGUARDSIZE 1
@@ -198,7 +193,7 @@
 #define HAVE_PTHREAD_ATTR_SETSTACKSIZE 1
 /* #undef HAVE_PTHREAD_CONDATTR_CREATE */
 #define HAVE_PTHREAD_KEY_DELETE 1
-#define HAVE_PTHREAD_KILL 1
+/* #undef HAVE_PTHREAD_KILL */
 #define HAVE_PTHREAD_RWLOCK_RDLOCK 1
 #define HAVE_PTHREAD_SIGMASK 1
 /* #undef HAVE_PTHREAD_YIELD_NP */
@@ -219,6 +214,7 @@
 #define HAVE_SIGACTION 1
 /* #undef HAVE_SIGTHREADMASK */
 #define HAVE_SIGWAIT 1
+#define HAVE_SIGWAITINFO 1
 #define HAVE_SLEEP 1
 #define HAVE_SNPRINTF 1
 #define HAVE_STPCPY 1
@@ -380,10 +376,10 @@
 /* #undef HAVE_SVR3_SIGNALS */
 /* #undef HAVE_V7_SIGNALS */
 #define HAVE_ERR_remove_thread_state 1
+#define HAVE_X509_check_host 1
 
 /* #undef HAVE_SOLARIS_STYLE_GETHOST */
 
-#define HAVE_GCC_ATOMIC_BUILTINS 1
 #define HAVE_GCC_C11_ATOMICS 1
 /* #undef HAVE_SOLARIS_ATOMIC */
 #define HAVE_DECL_SHM_HUGETLB 1
@@ -444,7 +440,11 @@
 /*
   MySQL features
 */
-#define ENABLED_LOCAL_INFILE 1
+#define LOCAL_INFILE_MODE_OFF  0
+#define LOCAL_INFILE_MODE_ON   1
+#define LOCAL_INFILE_MODE_AUTO 2
+#define ENABLED_LOCAL_INFILE LOCAL_INFILE_MODE_ON
+
 #define ENABLED_PROFILING 1
 /* #undef EXTRA_DEBUG */
 /* #undef USE_SYMDIR */
@@ -527,23 +527,23 @@
 #define MYSQL_DATADIR "/var/lib/mysql"
 #define DEFAULT_CHARSET_HOME "/usr"
 #define PLUGINDIR "/usr/lib/mysql/plugin"
-#define DEFAULT_SYSCONFDIR "/etc/mysql"
+#define DEFAULT_SYSCONFDIR "/etc"
 #define DEFAULT_TMPDIR P_tmpdir
 
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 3
-#define MYSQL_VERSION_PATCH 12
+#define MYSQL_VERSION_MINOR 4
+#define MYSQL_VERSION_PATCH 11
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.3.12"
+#define PACKAGE_STRING "MySQL Server 10.4.11"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.3.12"
-#define VERSION "10.3.12"
+#define PACKAGE_VERSION "10.4.11"
+#define VERSION "10.4.11"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
